@@ -25,7 +25,6 @@ def create_dir_if_not_exists(dir):
         os.makedirs(dir)
 
 
-# TODO remove function
 def recreate_dir(dir):
     if os.path.exists(dir):
         shutil.rmtree(dir)
@@ -36,6 +35,11 @@ def file_exists(file):
     return os.path.exists(file)
 
 
+def rename(old, new):
+    if file_exists(old):
+        os.rename(old, new)
+
+
 def remove_dirtree(dir):
     if os.path.exists(dir):
         shutil.rmtree(dir)
